@@ -8,23 +8,23 @@ RENAME_ATOMS = {
 }
 
 RESIDUE_REFSTATE = {
-    "HSD": "HI0",
-    "HSE": "HI1",
-    "HSP": "HI2",
-    "ARGN": "AR0",
-    "ASPH": "AS0",
+    "HSD": "HIS",
+    "HSE": "HIS",
+    "HSP": "HIS",
+    "ARGN": "ARG",
+    "ASPH": "ASP",
     "CYS1": "CYS",
     "CYS2": "CYS",
-    "CYSH": "CY0",
-    "GLUH": "GL0",
-    "HISD": "HI0",
-    "HISE": "HI1",
-    "HISH": "HI2",
-    "HISA": "HI0",
-    "HISB": "HI1",
-    "HISP": "HI2",
-    "LYSH": "LY3",
-    "LYSN": "LY0",
+    "CYSH": "CYS",
+    "GLUH": "GLU",
+    "HISD": "HIS",
+    "HISE": "HIS",
+    "HISH": "HIS",
+    "HISA": "HIS",
+    "HISB": "HIS",
+    "HISP": "HIS",
+    "LYSH": "LYS",
+    "LYSN": "LYS",
     "ISU": "CYS",
 }
 
@@ -64,4 +64,4 @@ PROTEIN_RESIDUES = (
     "TYR",
     "NTR",
     "CTR",
-)
\ No newline at end of file
+)
